@@ -5,6 +5,12 @@ from typing import List, Dict, Union
 
 
 def list_dict_group(data: List[Dict], key):
+    """
+    列表字典去重
+    :param data: 数据
+    :param key: 去重的key
+    :return:
+    """
     new_data = {"list_data": list(), "dict_data": dict()}
     data.sort(key=lambda x: x.get(key, ""))
     group_data = groupby(data, key=lambda x: x.get(key, ""))
@@ -61,14 +67,39 @@ def check_value(value, default):
 
 
 def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key: str = "growth_rate",
-                             start_growth_rate: float = None, flag: bool = True, digits: int = None):
+                             start_growth_rate: float = None, pre_value: Union[int, float] = None, flag: bool = True,
+                             digits: int = None):
+    """
+    检查或添加增长率字段
+    :param data: 数据
+    :param value_key: 数据的key
+    :param growth_rate_key: 增长率的key
+    :param start_growth_rate: 起始增长率
+    :param pre_value: 前一个数据
+    :param flag: 是否乘100
+    :param digits: 小数点位数
+    :return:
+    """
     for i, _ in enumerate(data):
-        if _.get(growth_rate_key) and value_key in _:
+        if not _.get(growth_rate_key) and value_key in _:
             if i == 0:
                 if start_growth_rate:
+                    if flag:
+                        start_growth_rate = start_growth_rate * 100
+                    if digits:
+                        start_growth_rate = round(start_growth_rate, digits)
                     data[i][growth_rate_key] = start_growth_rate
                 else:
-                    data[i][growth_rate_key] = 0
+                    if pre_value:
+                        current = check_value(data[i].get(value_key, 0), 0) if data[i].get(value_key, 0) else 0
+                        value = float(current - pre_value) / pre_value if pre_value else 0
+                    else:
+                        value = 0
+                    if flag:
+                        value = value * 100
+                    if digits:
+                        value = round(value, digits)
+                    data[i][growth_rate_key] = value
             else:
                 pre = check_value(data[i - 1].get(value_key, 0), 0) if data[i - 1].get(value_key, 0) else 0
                 current = check_value(data[i].get(value_key, 0), 0) if data[i].get(value_key, 0) else 0
